@@ -4,7 +4,8 @@ ITEM_TYPES = {
         [0xF1, 0xF1, 0xF1],
     ],
     "Magic": [
-        [0x75, 0x75, 0xFF]
+        # [0x75, 0x75, 0xFF]
+        [0xFF, 0x84, 0x85]
     ],
     "Rare": [
         [0xFF, 0xFF, 0x6B]
